# polyline-ruler

<!--intro-start-->

Init from [mapbox/cheap-ruler](https://github.com/mapbox/cheap-ruler) but more than that.

## Installation

### via pip

```bash
pip install -U polyline-ruler
```

### from source

```bash
git clone --recursive https://github.com/cubao/polyline-ruler
pip install ./polyline-ruler
```

Or

```bash
pip install git+https://github.com/cubao/polyline-ruler.git
```

(you can build wheels for later reuse by `pip wheel git+https://github.com/cubao/polyline-ruler.git`)

<!--intro-end-->

## Usage

See [`tests/test_basic.py`](tests/test_basic.py).

## Tests

```bash
python3 tests/test_basic.py
```
